@@ -182,19 +182,9 @@ class ContourLabeler(object):
         self.labelIndiceList = indices
 
         self.labelFontProps = font_manager.FontProperties()
-        if fontsize is None:
-            font_size = int(self.labelFontProps.get_size_in_points())
-        else:
-            if type(fontsize) not in [int, float, str]:
-                raise TypeError("Font size must be an integer number.")
-                # Can't it be floating point, as indicated in line above?
-            else:
-                if type(fontsize) == str:
-                    font_size = int(self.labelFontProps.get_size_in_points())
-                else:
-                    self.labelFontProps.set_size(fontsize)
-                    font_size = fontsize
-        self.labelFontSizeList = [font_size] * len(levels)
+        self.labelFontProps.set_size(fontsize)
+        font_size_pts = self.labelFontProps.get_size_in_points()
+        self.labelFontSizeList = [font_size_pts] * len(levels)
 
         if _colors is None:
             self.labelMappable = self
@@ -1192,6 +1182,12 @@ class ContourSet(cm.ScalarMappable, ContourLabeler):
         if self.filled and len(self.levels) < 2:
             raise ValueError("Filled contours require at least 2 levels.")
 
+        if len(self.levels) > 1 and np.amin(np.diff(self.levels)) <= 0.0:
+            if hasattr(self, '_corner_mask') and self._corner_mask == 'legacy':
+                warnings.warn("Contour levels are not increasing")
+            else:
+                raise ValueError("Contour levels must be increasing")
+
     def _process_levels(self):
         """
         Assign values to :attr:`layers` based on :attr:`levels`,
@@ -1442,16 +1438,16 @@ class QuadContourSet(ContourSet):
             else:
                 contour_generator = args[0]._contour_generator
         else:
+            self._corner_mask = kwargs.get('corner_mask', None)
+            if self._corner_mask is None:
+                self._corner_mask = mpl.rcParams['contour.corner_mask']
+
             x, y, z = self._contour_args(args, kwargs)
 
             _mask = ma.getmask(z)
             if _mask is ma.nomask or not _mask.any():
                 _mask = None
 
-            self._corner_mask = kwargs.get('corner_mask', None)
-            if self._corner_mask is None:
-                self._corner_mask = mpl.rcParams['contour.corner_mask']
-
             if self._corner_mask == 'legacy':
                 cbook.warn_deprecated('1.5',
                                       name="corner_mask='legacy'",
@@ -1674,13 +1670,15 @@ class QuadContourSet(ContourSet):
           contour(Z,V)
           contour(X,Y,Z,V)
 
-        draw contour lines at the values specified in sequence *V*
+        draw contour lines at the values specified in sequence *V*,
+        which must be in increasing order.
 
         ::
 
           contourf(..., V)
 
-        fill the ``len(V)-1`` regions between the values in *V*
+        fill the ``len(V)-1`` regions between the values in *V*,
+        which must be in increasing order.
 
         ::
 
@@ -1743,8 +1741,8 @@ class QuadContourSet(ContourSet):
 
           *levels*: [level0, level1, ..., leveln]
             A list of floating point numbers indicating the level
-            curves to draw; e.g., to draw just the zero contour pass
-            ``levels=[0]``
+            curves to draw, in increasing order; e.g., to draw just
+            the zero contour pass ``levels=[0]``
 
           *origin*: [ *None* | 'upper' | 'lower' | 'image' ]
             If *None*, the first value of *Z* will correspond to the
